Enables or disables local caching for O*NET API responses. Caching is off by default because API results may change over time, but it is useful when developing analyses that repeatedly request the same endpoints.
Usage
onet_cache_use(
enabled = TRUE,
cache_dir = tools::R_user_dir("onet2r", "cache")
)Details
Cached Web Services responses are reused until the caller disables caching
or clears them with onet_cache_clear(). The package does not attach a
time-to-live, so enable caching only when stale O*NET API responses are
acceptable for the analysis.