Retrieves a list of available database tables in O*NET.
Examples
if (FALSE) { # interactive() && nzchar(Sys.getenv("ONET_API_KEY"))
tables <- onet_tables()
head(tables)
}
Retrieves a list of available database tables in O*NET.
if (FALSE) { # interactive() && nzchar(Sys.getenv("ONET_API_KEY"))
tables <- onet_tables()
head(tables)
}