Parses the O*NET database releases archive and returns downloadable text
archives. The release archive states release months, not days, so
release_date uses the first day of each stated month.
Examples
if (interactive()) {
onet_releases()
}
Parses the O*NET database releases archive and returns downloadable text
archives. The release archive states release months, not days, so
release_date uses the first day of each stated month.
if (interactive()) {
onet_releases()
}